# -*- coding: utf-8 -*-

from zope.interface import Interface

##code-section HEAD
##/code-section HEAD

class IRDV_RendezVous(Interface):
    """Marker interface for .RDV_RendezVous.RDV_RendezVous
    """

class IRDV_Proposition(Interface):
    """Marker interface for .RDV_Proposition.RDV_Proposition
    """

##code-section FOOT
##/code-section FOOT