#rendezvous {
/*  border-collapse: collapse;*/
}

#rendezvous td {
  width: 10ex;
}

#rendezvous .noborder {
  width: 20ex;
}

#rendezvous .rendezvousdates th {
  background-color: #dddddd;
  border-color: #aaaaaa;
}

#rendezvous th, #rendezvous td {
  background-color: #ededed;
  border: 1px solid #cacaca;
  text-align: center;
}
#region-content #rendezvous .noborder {
  border: none;
  background-color: transparent;
}

#rendezvous td.available {
  background-color: #a8ffa6; /* green */
  border-color: #64d06a;
  color: #399e39;
}

#rendezvous td.unavailable {
  background-color: #ffaca8; /* red */
  border-color: #e88782;
}

#rendezvous td.unknown {
  background-color: #eef6fe; /* light blue */
  border-color: #0066dd;
  color: #0066dd;
}
